pub struct MetadataProperty {
pub name: String,
pub data_type: TdmsDataType,
pub value: TDMSValue,
}Expand description
MetadataProperty is a key/value pair associated with a MetadataObject
Fields
name: Stringdata_type: TdmsDataTypevalue: TDMSValueImplementations
Sourceimpl MetadataProperty
impl MetadataProperty
Sourcepub fn from_reader<R: Read + Seek>(
endianness: Endianness,
r: &mut R,
) -> Result<Self, TdmsError>
pub fn from_reader<R: Read + Seek>( endianness: Endianness, r: &mut R, ) -> Result<Self, TdmsError>
from_reader accepts an open reader and attempts to read metadata properties from the currently selected segment and metadata object. Note that you must have read the metadata object’s lead in information prior to using this function